Python MSS
==========

.. image:: https://travis-ci.org/BoboTiG/python-mss.svg?branch=dev
    :target: https://travis-ci.org/BoboTiG/python-mss

An ultra fast cross-platform multiple screenshots module in pure python using ctypes.

- **Python 2 & 3** and PEP8 compliant, no dependency;
- very basic, it will grab one screen shot by monitor or a screen shot of all monitors and save it to a PNG file;
- but you can use PIL and benefit from all its formats (or add yours directly);
- it could be easily embedded into games and other softwares which require fast and plateforme optimized methods to grab screenshots;
- get the `source code on GitHub <https://github.com/BoboTiG/python-mss>`_;
- you can `report a bug <https://github.com/BoboTiG/python-mss/issues>`_;
- and there is a `complete, and beautiful, documentation <https://python-mss.readthedocs.io>`_ :)
- **MSS** stands for Multiple ScreenShots;
- insanely fast, did I say it?


Installation
------------

You can install it with pip::

    pip install --upgrade mss
